# toolbox of goodies

## squirrel.py

simple commandline wrapper around credstash

## treeify.py

display items in an ascii tree format

## GoogleMaps.py

query the google maps api from the command line


